@@ -5,7 +5,7 @@
 **
 ** Comments: Dump IP header information
 **
-** $Id: ip.c,v 1.24 2001/11/15 00:22:36 mborella Exp $
+** $Id: ip.c,v 1.25 2002/01/03 00:04:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
 #include "ip_protocols.h"
 #include "ip_services.h"
 
+#define HOLDER_SIZE 64
+
 /* 
  * Contains the descriptions of IP options
  */
@@ -213,7 +215,7 @@ void dump_ip_options(packet_t *pkt, u_int8_t length)
 {
   u_int8_t bytes_read = 0;
   ip_option_t opt;
-  char holder[64];
+  char holder[HOLDER_SIZE];
 
   while(bytes_read < length)
     {
@@ -229,7 +231,7 @@ void dump_ip_options(packet_t *pkt, u_int8_t length)
        * Display it
        */
       
-      sprintf(holder, "%d (%s)", opt.code, 
+      snprintf(holder, HOLDER_SIZE, "%d (%s)", opt.code, 
 	      map2str(ip_option_map, opt.code));
       
       if (!my_args->m)
