@@ -6,7 +6,7 @@
 **
 ** Comments: Dump TCP header information. 
 **
-** $Id: tcp.c,v 1.23 2001/10/12 21:45:02 mborella Exp $
+** $Id: tcp.c,v 1.24 2002/01/03 00:04:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 #include "tcp.h"
 #include "payload.h"
 
+#define HOLDER_SIZE 64
+
 /* 
  * TCP option map 
  */
@@ -61,7 +63,7 @@ extern strmap_t port_map[];
 void dump_tcp_options(packet_t *pkt, u_int8_t length)
 {
   u_int8_t option_bytes_read;
-  char holder[64];
+  char holder[HOLDER_SIZE];
   u_int8_t option_length;
   u_int8_t kind;
   u_int16_t mss;
@@ -84,8 +86,8 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
 	{
 	  if (!my_args->m)
 	    {
-	      sprintf(holder, "%d (%s)", kind, 
-		      map2str(tcp_option_map, kind));
+	      snprintf(holder, HOLDER_SIZE, "%d (%s)", kind, 
+		       map2str(tcp_option_map, kind));
 	      display_string("Option", holder);
 	    }
 	  continue;
@@ -94,8 +96,8 @@ void dump_tcp_options(packet_t *pkt, u_int8_t length)
       /* display the option's name */
       if (!my_args->m)
 	{
-	  sprintf(holder, "%d (%s)", kind, 
-		  map2str(tcp_option_map, kind));
+	  snprintf(holder, HOLDER_SIZE, "%d (%s)", kind, 
+		   map2str(tcp_option_map, kind));
 	  display_string("Option", holder);
 	}
       else 
@@ -307,7 +309,7 @@ void dump_tcp(packet_t *pkt)
 	      DISP_DEC);
       
       /* header length and unused bits */
-      sprintf(holder, "%d (%d bytes)", hlen, hlen*4);   
+      snprintf(holder, HOLDER_SIZE, "%d (%d bytes)", hlen, hlen*4);   
       display_string("Header length", holder);
       display("Unused", (u_int8_t *) &unused, 1, DISP_DEC);
       
